ColumnType enum

Primitive Dart types known by DataAccess.showCreateTable.

When a column value is null in an entity's toMap(), the entity uses one of these constants to tell the package which SQL column type to generate for that column.

Inheritance
Available extensions

Values

int → const ColumnType
double → const ColumnType
String → const ColumnType
bool → const ColumnType
DateTime → const ColumnType
Uint8List → const ColumnType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColumnType>
A constant List of the values in this enum, in order of their declaration.