databasesPath property
Directory where SQLite database files are stored.
The directory is not created on disk automatically - create it from the client code if you want to make sure it exists before writing.
Implementation
Future<String> get databasesPath async {
_databasesPath ??=
'${getParentDir(await rootPath)}${pathJoin}databases';
return _databasesPath!;
}